@@ -57,7 +57,10 @@ perm.tests = function(m0, m1, r0, r1, lowthresh=1E-12)
  	waldT0 = betahat0/sehat0
 	
 	# Firth test
-	m.firth = logistf(c(1,1,0,0) ~ c(1,0,1,0), weights=c(r1, m1-r1, r0, m0-r0))
+ 	y = c(1,1,0,0)
+ 	x = c(1,0,1,0)
+ 	data = data.frame(y = y, x = x)
+	m.firth = logistf(y~x, data=data, weights=c(r1, m1-r1, r0, m0-r0))
 	firth.t = sum(c(-2, 2)*m.firth$loglik)
 	firth.p = m.firth$prob[2]
 
@@ -68,8 +71,8 @@ perm.tests = function(m0, m1, r0, r1, lowthresh=1E-12)
   if (length(delrows) > 0) dd = dd[-delrows,]
  	dd$prob = dhyper(dd$r1x, r0+r1, m0+m1-r0-r1, m1)
 	
-	dd$firthx = sapply(1:nrow(dd), function(x) sum(c(-2,2)*(logistf(c(1,1,0,0) ~ c(1,0,1,0), 
-	weights=c(dd$r1x[x], m1-dd$r1x[x], dd$r0x[x], m0-dd$r0x[x]))$loglik)))
+	dd$firthx = sapply(1:nrow(dd), function(xx) sum(c(-2,2)*(logistf(y~x, data=data, 
+	weights=c(dd$r1x[xx], m1-dd$r1x[xx], dd$r0x[xx], m0-dd$r0x[xx]))$loglik)))
 	
  	dd$px = with(dd, (r0x+r1x)/(m0+m1) )
  	dd$tx = with(dd, r1x*(1-ybar) - r0x*ybar )
